@@ -6,12 +6,11 @@ import logging
 import sys
 from getpass import getpass
 from pathlib import Path
-from pprint import pprint
 
 if __name__ == "__main__":
     sys.path.insert(0, str(Path(__file__).parent.parent))
 
-from pyhon import HonConnection
+from pyhon import Hon, HonAPI
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -25,8 +24,12 @@ def get_arguments():
     keys = subparser.add_parser("keys", help="print as key format")
     keys.add_argument("keys", help="print as key format", action="store_true")
     keys.add_argument("--all", help="print also full keys", action="store_true")
-    translate = subparser.add_parser("translate", help="print available translation keys")
-    translate.add_argument("translate", help="language (de, en, fr...)", metavar="LANGUAGE")
+    translate = subparser.add_parser(
+        "translate", help="print available translation keys"
+    )
+    translate.add_argument(
+        "translate", help="language (de, en, fr...)", metavar="LANGUAGE"
+    )
     translate.add_argument("--json", help="print as json", action="store_true")
     return vars(parser.parse_args())
 
@@ -51,7 +54,9 @@ def pretty_print(data, key="", intend=0, is_list=False):
             else:
                 pretty_print(value, key=key, intend=intend)
     else:
-        print(f"{'  ' * intend}{'- ' if is_list else ''}{key}{': ' if key else ''}{data}")
+        print(
+            f"{'  ' * intend}{'- ' if is_list else ''}{key}{': ' if key else ''}{data}"
+        )
 
 
 def key_print(data, key="", start=True):
@@ -85,12 +90,17 @@ def create_command(commands, concat=False):
 
 
 async def translate(language, json_output=False):
-    async with HonConnection() as hon:
+    async with HonAPI(anonymous=True) as hon:
         keys = await hon.translation_keys(language)
     if json_output:
         print(json.dumps(keys, indent=4))
     else:
-        clean_keys = json.dumps(keys).replace("\\n", "\\\\n").replace("\\\\r", "").replace("\\r", "")
+        clean_keys = (
+            json.dumps(keys)
+            .replace("\\n", "\\\\n")
+            .replace("\\\\r", "")
+            .replace("\\r", "")
+        )
         keys = json.loads(clean_keys)
         pretty_print(keys)
 
@@ -104,8 +114,8 @@ async def main():
         user = input("User for hOn account: ")
     if not (password := args["password"]):
         password = getpass("Password for hOn account: ")
-    async with HonConnection(user, password) as hon:
-        for device in hon.devices:
+    async with Hon(user, password) as hon:
+        for device in hon.appliances:
             print("=" * 10, device.appliance_type, "-", device.nick_name, "=" * 10)
             if args.get("keys"):
                 data = device.data.copy()
@@ -126,5 +136,5 @@ def start():
         print("Aborted.")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     start()
